==> kubernetes-model-1.0.15-sources.jar: annotations/io/fabric8/openshift/api/model/NamedClusterRoleBindingBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class NamedClusterRoleBindingBuilder extends NamedClusterRoleBindingFluent<NamedClusterRoleBindingBuilder> implements VisitableBuilder<NamedClusterRoleBinding,NamedClusterRoleBindingBuilder>{

     NamedClusterRoleBindingFluent<?> fluent;
public NamedClusterRoleBindingBuilder(){
    this(new NamedClusterRoleBinding());
}
public NamedClusterRoleBindingBuilder( NamedClusterRoleBindingFluent<?> fluent ){
    this(fluent, new NamedClusterRoleBinding());
}
public NamedClusterRoleBindingBuilder( NamedClusterRoleBindingFluent<?> fluent , NamedClusterRoleBinding instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withRoleBinding(instance.getRoleBinding()); 
}
public NamedClusterRoleBindingBuilder( NamedClusterRoleBinding instance ){
    this.fluent = this; this.withName(instance.getName()); this.withRoleBinding(instance.getRoleBinding()); 
}

public EditableNamedClusterRoleBinding build(){
    EditableNamedClusterRoleBinding buildable = new EditableNamedClusterRoleBinding(fluent.getName(),fluent.getRoleBinding());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedClusterRoleBindingBuilder that = (NamedClusterRoleBindingBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.30-sources.jar: annotations/io/fabric8/openshift/api/model/NamedClusterRoleBindingBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class NamedClusterRoleBindingBuilder extends NamedClusterRoleBindingFluentImpl<NamedClusterRoleBindingBuilder> implements VisitableBuilder<NamedClusterRoleBinding,NamedClusterRoleBindingBuilder>{

     NamedClusterRoleBindingFluent<?> fluent;
public NamedClusterRoleBindingBuilder(){
    this(new NamedClusterRoleBinding());
}
public NamedClusterRoleBindingBuilder( NamedClusterRoleBindingFluent<?> fluent ){
    this(fluent, new NamedClusterRoleBinding());
}
public NamedClusterRoleBindingBuilder( NamedClusterRoleBindingFluent<?> fluent , NamedClusterRoleBinding instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withRoleBinding(instance.getRoleBinding()); 
}
public NamedClusterRoleBindingBuilder( NamedClusterRoleBinding instance ){
    this.fluent = this; this.withName(instance.getName()); this.withRoleBinding(instance.getRoleBinding()); 
}

public EditableNamedClusterRoleBinding build(){
    EditableNamedClusterRoleBinding buildable = new EditableNamedClusterRoleBinding(fluent.getName(),fluent.getRoleBinding());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedClusterRoleBindingBuilder that = (NamedClusterRoleBindingBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
